@@ -1,4 +1,5 @@
-from numpy import asarray, copy, copyto, einsum, sum
+from numpy import sum as _sum
+from numpy import asarray, copy, copyto, einsum
 
 
 def trace2(A, B):
@@ -15,7 +16,7 @@ def trace2(A, B):
     B = asarray(B, float)
     assert len(A.shape) == 2 and len(B.shape) == 2
     assert A.shape[1] == B.shape[0] and A.shape[0] == B.shape[1]
-    return sum(A.T * B)
+    return _sum(A.T * B)
 
 
 def sum2diag(A, D, out=None):
